@@ -3,9 +3,13 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 use Carp;
+use Exporter;
+
+our @ISA = qw(Exporter);
+our @EXPORT_OK = qw (pread pwrite);
 
 sub new {
     return bless {}, shift;
@@ -106,7 +110,8 @@ sub recsep {
     return if ! $contents[0];
 
     if ($contents[0] =~ /(\R)/){
-        $self->{recsep} = $1;;
+        $self->{recsep} = $1;
+        $ENV{FEP_RECSEP} = $1;
     }
 
     my $recsep = unpack "H*", $self->{recsep};
@@ -144,6 +149,73 @@ sub platform_recsep {
 
     return $self->{platform_recsep};
 }
+sub pread {
+    my ($file, $testing) = @_; 
+
+    my $rw = File::Edit::Portable->new;
+
+    $ENV{FEP_IS_READ} = 1;
+
+    if (! $file){ 
+        croak "pread() requires a file name sent in!";
+    }
+
+    $rw->recsep($file);
+
+    my $fh = $rw->_open($file);
+
+    if (! wantarray){
+        my $handle = $rw->_handle($file);
+        return $handle;
+    }
+    else {
+
+        my @contents = <$fh>;
+        close $fh or croak "read() can't close file $file!: $!";
+
+        if (! $testing){
+            for (@contents){
+                s/\R//;
+            }
+        }
+        return @contents;
+    }
+}
+sub pwrite {
+
+    my ($file, $contents, $copy, $recsep) = @_;
+
+    my $rw = File::Edit::Portable->new;
+
+    if (! $file){
+        croak "write() requires a file to be passed in!";
+    }
+
+    if (! $contents){
+        croak "write() requires 'contents' param sent in";
+    }
+
+    $rw->recsep($file);
+
+    $file = $copy if $copy;
+
+    my $wfh = $rw->_open($file, 'w');
+
+    for (@$contents){
+        s/\R//;
+
+        if ($recsep){
+            print $wfh $_ . $recsep;
+        }
+       else {
+            print $wfh $_ . $rw->{recsep};
+        }
+    }
+
+    close $wfh or croak "write() can't close file $file: $!";
+
+    return 1;
+}
 sub _config {
 
     my $self = shift;
@@ -256,6 +328,20 @@ Get the local platforms record separator. This will be in string representation.
 
     my $platform_recsep = $rw->platform_recsep;
 
+There's also a non-OO interface...
+
+    use File::Edit::Portable qw(pread pwrite);
+
+    my $fh = pread('file.txt');
+
+    # and/or
+
+    my @contents = pread('file.txt');
+
+    # then
+
+    pwrite('file.txt', \@contents);
+
 
 =head1 DESCRIPTION
 
@@ -265,6 +351,15 @@ This module will read in a file, keep track of the file's current record separat
 
 Uses are for dynamically reading/writing files while on one Operating System, but you don't know whether the record separators are platform-standard. Shared storage between multpile platforms are a good use case. This module affords you the ability to not have to check each file, and is very useful in looping over a directory where various files may have been written by different platforms.
 
+=head1 EXPORT
+
+None by default. See L<EXPORT_OK>
+
+=head1 EXPORT_OK
+
+If you desire using the non-OO functionality, the following functions are exported on demand.
+
+C<pread()> and C<pwrite()>
 
 =head1 METHODS
 
@@ -306,6 +401,19 @@ Returns a string of the hex representation of the line endings (record separator
 
 Returns the string representation of the current platform's (OS) record separator. Takes no parameters.
 
+=head1 FUNCTIONS
+
+=head2 C<pread('file.txt')>
+
+In scalar context, will return a read-only file handle. In list context, returns an array with each element being a line in the file, with the endings stripped off.
+
+=head2 C<pwrite('file.txt', \@contents, 'copy.txt', "\r\n")>
+
+Writes back out the file (or alternately a new file (copy.txt), using the original file's line endings, or optionally a custom record separator as specified by the last parameter. Note the record separator MUST be sent in within double-quotes.
+
+If you want to send in a custom record separator but not use a copy file, just set the third parameter (copy.txt) to C<undef> within the call.
+
+
 =head1 AUTHOR
 
 Steve Bertrand, C<< <steveb at cpan.org> >>
